@@ -2,7 +2,8 @@
 
 # Build API URL
 get_url <- function(api, path, resource = NULL) {
-  url_root <- paste0("https://www3.gobiernodecanarias.org/istac/api/", api, "/v1.0/")
+
+  url_root <- paste0("https://datos.canarias.es/api/estadisticas/", api, "/v1.0/")
 
   if (is.null(resource)) {
     url <- paste0(url_root, path)
@@ -13,6 +14,35 @@ get_url <- function(api, path, resource = NULL) {
   return(url)
 }
 
+# Get content from URL
+get_content <- function(url) {
+
+  content <- NULL
+
+  tryCatch(
+    # Try to get content JSON from ISTAC api
+    expr = {
+      content <- fromJSON(url)
+    },
+    # Catch errors
+    error = function(e){
+      message('Oops! An error occurred while accessing the ISTAC api')
+      content <- NULL
+      print(e)
+    },
+    # Catch warnings
+    warning = function(w){
+      message('Oops! Some warnings ocurred')
+      content <- NULL
+      print(w)
+    }
+
+  )
+
+  return(content)
+
+}
+
 # Example: parse_param("GEOGRAPHICAL[MUNICIPALITIES]")
 parse_param <- function(param) {
   param <- trimws(param) # Remove white spaces
