@@ -32,7 +32,7 @@ get_datasets <- function(lang = "es", limit = 25, offset = 0, orderBy = NULL, qu
   url <- get_url(api, path)
 
   # Get content
-  content <- fromJSON(url)
+  content <- get_content(url)
 
   return(content)
 
@@ -71,7 +71,7 @@ get_datasets_agency <- function(agencyID, lang = "es", limit = 25, offset = 0, o
   url <- get_url(api, path, resource)
 
   # Get content
-  content <- fromJSON(url)
+  content <- get_content(url)
 
   return(content)
 
@@ -111,7 +111,7 @@ get_datasets_agency_resource <- function(agencyID, resourceID, lang = "es", limi
   url <- get_url(api, path, resource)
 
   # Get content
-  content <- fromJSON(url)
+  content <- get_content(url)
 
   return(content)
 
@@ -153,7 +153,7 @@ get_datasets_agency_resource_version <- function(agencyID, resourceID, version,
   url <- get_url(api, path, resource)
 
   # Get content
-  content <- fromJSON(url)
+  content <- get_content(url)
 
   return(content)
 
